@@ -1,5 +1,8 @@
 `audpc` <-
 function(evaluation, dates, type = "absolute") {
+if(!(is.matrix(evaluation) | is.data.frame(evaluation))){
+evaluation<-rbind(evaluation)
+}
 n<-length(dates)
 k<-ncol(evaluation)
 if (n!=k) {
@@ -11,7 +14,7 @@ area.total<- 100*(dates[n]-dates[1])
 for (i in 1:(n-1)) {
 audpc<- audpc + (evaluation[,i]+evaluation[,i+1])*(dates[i+1]-dates[i])/2
 }
-if (type == "relative" ) audpc <-audpc/area.total
+if (type =="relative" ) audpc <-audpc/area.total
 if (type =="absolute" | type =="relative" ) {
 return(audpc)
 }
